@@ -578,6 +578,11 @@ pref("network.http.pipelining.maxrequests" , 4);
 
 // </http>
 
+// If false, remote JAR files that are served with a content type other than
+// application/java-archive or application/x-jar will not be opened
+// by the jar channel.
+pref("network.jar.open-unsafe-types", false);
+
 // This preference controls whether or not internationalized domain names (IDN)
 // are handled.  IDN requires a nsIIDNService implementation.
 pref("network.enableIDN", true);
@@ -603,16 +608,19 @@ pref("network.IDN.whitelist.cl", true);
 pref("network.IDN.whitelist.cn", true);
 pref("network.IDN.whitelist.de", true);
 pref("network.IDN.whitelist.dk", true);
+pref("network.IDN.whitelist.es", true);
 pref("network.IDN.whitelist.fi", true);
 pref("network.IDN.whitelist.gr", true);
 pref("network.IDN.whitelist.hu", true);
 pref("network.IDN.whitelist.io", true);
+pref("network.IDN.whitelist.ir", true);
 pref("network.IDN.whitelist.is", true);
 pref("network.IDN.whitelist.jp", true);
 pref("network.IDN.whitelist.kr", true);
 pref("network.IDN.whitelist.li", true);
 pref("network.IDN.whitelist.lt", true);
 pref("network.IDN.whitelist.no", true);
+pref("network.IDN.whitelist.pl", true);
 pref("network.IDN.whitelist.se", true);
 pref("network.IDN.whitelist.sh", true);
 pref("network.IDN.whitelist.th", true);
@@ -684,7 +692,7 @@ pref("network.negotiate-auth.gsslib", "");
 // Specify if the gss lib comes standard with the OS
 pref("network.negotiate-auth.using-native-gsslib", true);
 
-//@line 698 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 706 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
 // The following prefs are used to enable automatic use of the operating
 // system's NTLM implementation to silently authenticate the user with their
@@ -832,7 +840,7 @@ pref("mousewheel.withmetakey.sysnumlines",true);
 
 // on platforms where scroll messages differ between horizontal scroll
 // and back/forward button events we can activate them by default
-//@line 880 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 888 "/tmp/mozilla/modules/libpref/src/init/all.js"
 // disable horizontal scrolling to be able to use back/forward buttons
 pref("mousewheel.horizscroll.withnokey.action",2);
 pref("mousewheel.horizscroll.withnokey.numlines",-1);
@@ -849,7 +857,7 @@ pref("mousewheel.horizscroll.withaltkey.sysnumlines",false);
 pref("mousewheel.horizscroll.withmetakey.action",2);
 pref("mousewheel.horizscroll.withmetakey.numlines",-1);
 pref("mousewheel.horizscroll.withmetakey.sysnumlines",false);
-//@line 897 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 905 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
 pref("profile.confirm_automigration",true);
 // profile.migration_behavior determines how the profiles root is set
@@ -992,15 +1000,15 @@ pref("dom.max_script_run_time", 10);
 
 pref("svg.enabled", true);
 
-//@line 1370 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1378 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1562 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1570 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1751 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1759 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1840 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1848 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 1843 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1851 "/tmp/mozilla/modules/libpref/src/init/all.js"
 // Handled differently under Mac/Windows
 pref("network.hosts.smtp_server", "localhost");
 pref("network.hosts.pop_server", "pop");
@@ -1073,7 +1081,7 @@ pref("font.allow_double_byte_special_chars", true);
 
 // ar
 
-//@line 1916 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 1924 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.name.serif.el", "serif");
 pref("font.name.sans-serif.el", "sans-serif");
@@ -1132,7 +1140,7 @@ pref("font.name.sans-serif.zh-HK", "sans-serif");
 pref("font.name.monospace.zh-HK", "monospace");
 
 // zh-TW
-//@line 2035 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 2043 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
 pref("font.default.ar", "sans-serif");
 pref("font.size.variable.ar", 16);
@@ -1350,11 +1358,15 @@ pref("print.postscript.nativefont.zh-CN",          "");
 pref("print.postscript.nativefont.zh-TW",          "");
 pref("print.postscript.nativefont.zh-HK",          "");
 
-//@line 2255 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 2263 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2323 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 2331 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2349 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 2357 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
-//@line 2369 "/tmp/mozilla/modules/libpref/src/init/all.js"
+//@line 2377 "/tmp/mozilla/modules/libpref/src/init/all.js"
 
+//@line 2385 "/tmp/mozilla/modules/libpref/src/init/all.js"
+
+//@line 2387 "/tmp/mozilla/modules/libpref/src/init/all.js"
+pref("network.gnomevfs.supported-protocols", "smb:,sftp:");
